@@ -1,11 +1,13 @@
 import builtins
 import os
+from rich.repr import RichReprResult
 import sys
 from array import array
 from collections import Counter, defaultdict, deque, UserDict, UserList
 from dataclasses import dataclass, fields, is_dataclass
 from inspect import isclass
 from itertools import islice
+import re
 from typing import (
     DefaultDict,
     TYPE_CHECKING,
@@ -58,6 +60,9 @@ if TYPE_CHECKING:
         RenderResult,
     )
 
+# Matches Jupyter's special methods
+_re_jupyter_repr = re.compile(f"^_repr_.+_$")
+
 
 def install(
     console: Optional["Console"] = None,
@@ -112,11 +117,10 @@ def install(
         # always skip rich generated jupyter renderables or None values
         if isinstance(value, JupyterRenderable) or value is None:
             return
-        # on jupyter rich display, if using one of the special representations dont use rich
-        if console.is_jupyter and any(attr.startswith("_repr_") for attr in dir(value)):
-            return
-
-        if hasattr(value, "_repr_mimebundle_"):
+        # on jupyter rich display, if using one of the special representations don't use rich
+        if console.is_jupyter and any(
+            _re_jupyter_repr.match(attr) for attr in dir(value)
+        ):
             return
 
         # certain renderables should start on a new line
@@ -136,6 +140,7 @@ def install(
                 margin=12,
             ),
             crop=crop,
+            new_line_start=True,
         )
 
     try:  # pragma: no cover
@@ -470,7 +475,7 @@ def traverse(
             try:
                 obj_repr = repr(obj)
             except Exception as error:
-                obj_repr = f"<repr-error '{error}'>"
+                obj_repr = f"<repr-error {str(error)!r}>"
         return obj_repr
 
     visited_ids: Set[int] = set()
@@ -499,9 +504,24 @@ def traverse(
                 else:
                     yield arg
 
-        if hasattr(obj, "__rich_repr__") and not isclass(obj):
+        try:
+            fake_attributes = hasattr(
+                obj, "awehoi234_wdfjwljet234_234wdfoijsdfmmnxpi492"
+            )
+        except Exception:
+            fake_attributes = False
+
+        rich_repr_result: Optional[RichReprResult] = None
+        if not fake_attributes:
+            try:
+                if hasattr(obj, "__rich_repr__") and not isclass(obj):
+                    rich_repr_result = obj.__rich_repr__()
+            except Exception:
+                pass
+
+        if rich_repr_result is not None:
             angular = getattr(obj.__rich_repr__, "angular", False)
-            args = list(iter_rich_args(obj.__rich_repr__()))
+            args = list(iter_rich_args(rich_repr_result))
             class_name = obj.__class__.__name__
 
             if args:
@@ -540,7 +560,7 @@ def traverse(
                     children=[],
                     last=root,
                 )
-        elif _is_attr_object(obj):
+        elif _is_attr_object(obj) and not fake_attributes:
             children = []
             append = children.append
 
@@ -588,6 +608,7 @@ def traverse(
         elif (
             is_dataclass(obj)
             and not isinstance(obj, type)
+            and not fake_attributes
             and (
                 "__create_fn__" in obj.__repr__.__qualname__ or py_version == (3, 6)
             )  # Check if __repr__ wasn't overridden
